@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Iterator::Rule;
 # ABSTRACT: Iterative, recursive file finder
-our $VERSION = '1.007'; # VERSION
+our $VERSION = '1.010';
 
 # Register warnings category
 use warnings::register;
@@ -432,6 +432,7 @@ sub _regexify {
     my ( $re, $add ) = @_;
     $add ||= '';
     my $new = ref($re) eq 'Regexp' ? $re : Text::Glob::glob_to_regex($re);
+    return $new unless $add;
     my ( $pattern, $flags ) = regexp_pattern($new);
     my $new_flags = $add ? _reflag( $flags, $add ) : "";
     return qr/$new_flags$pattern/;
@@ -660,8 +661,11 @@ my %vcs_rules = (
     skip_hg => sub {
         return Path::Iterator::Rule->new->skip_dirs('.hg');
     },
+    skip_darcs => sub {
+        return Path::Iterator::Rule->new->skip_dirs('_darcs');
+    },
     skip_vcs => sub {
-        return Path::Iterator::Rule->new->skip_dirs(qw/.git .bzr .hg CVS RCS/)
+        return Path::Iterator::Rule->new->skip_dirs(qw/.git .bzr .hg _darcs CVS RCS/)
           ->skip_svn->not_name( qr/\.\#$/, qr/,v$/ );
     },
 );
@@ -714,7 +718,7 @@ Path::Iterator::Rule - Iterative, recursive file finder
 
 =head1 VERSION
 
-version 1.007
+version 1.010
 
 =head1 SYNOPSIS
 
@@ -1129,6 +1133,7 @@ of Perl distribution files.
   $rule->skip_git;
   $rule->skip_bzr;
   $rule->skip_hg;
+  $rule->skip_darcs;
 
 Skips files and/or prunes directories related to a version control system.
 Just like C<skip_dirs>, these rules should be specified early to get the
@@ -1531,6 +1536,8 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords David Steinbrunner Gian Piero Carrubba Graham Knop Ricardo Signes Slaven Rezic Toby Inkster
+
 =over 4
 
 =item *
@@ -1539,6 +1546,10 @@ David Steinbrunner <dsteinbrunner@pobox.com>
 
 =item *
 
+Gian Piero Carrubba <gpiero@butterfly.fdc.rm-rf.it>
+
+=item *
+
 Graham Knop <haarg@cpan.org>
 
 =item *
@@ -1547,6 +1558,10 @@ Ricardo Signes <rjbs@cpan.org>
 
 =item *
 
+Slaven Rezic <slaven.rezic@idealo.de>
+
+=item *
+
 Toby Inkster <tobyink@cpan.org>
 
 =back
